==> openshift-model-whereabouts-5.12.0-sources.jar: io/fabric8/openshift/api/model/whereabouts/v1alpha1/IPPoolListBuilder.java <==
package io.fabric8.openshift.api.model.whereabouts.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class IPPoolListBuilder extends io.fabric8.openshift.api.model.whereabouts.v1alpha1.IPPoolListFluentImpl<io.fabric8.openshift.api.model.whereabouts.v1alpha1.IPPoolListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.whereabouts.v1alpha1.IPPoolList,io.fabric8.openshift.api.model.whereabouts.v1alpha1.IPPoolListBuilder>{
  public IPPoolListBuilder() {
    this(false);
  }
  public IPPoolListBuilder(java.lang.Boolean validationEnabled) {
    this(new IPPoolList(), validationEnabled);
  }
  public IPPoolListBuilder(io.fabric8.openshift.api.model.whereabouts.v1alpha1.IPPoolListFluent<?> fluent) {
    this(fluent, false);
  }
  public IPPoolListBuilder(io.fabric8.openshift.api.model.whereabouts.v1alpha1.IPPoolListFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new IPPoolList(), validationEnabled);
  }
  public IPPoolListBuilder(io.fabric8.openshift.api.model.whereabouts.v1alpha1.IPPoolListFluent<?> fluent,io.fabric8.openshift.api.model.whereabouts.v1alpha1.IPPoolList instance) {
    this(fluent, instance, false);
  }
  public IPPoolListBuilder(io.fabric8.openshift.api.model.whereabouts.v1alpha1.IPPoolListFluent<?> fluent,io.fabric8.openshift.api.model.whereabouts.v1alpha1.IPPoolList instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public IPPoolListBuilder(io.fabric8.openshift.api.model.whereabouts.v1alpha1.IPPoolList instance) {
    this(instance,false);
  }
  public IPPoolListBuilder(io.fabric8.openshift.api.model.whereabouts.v1alpha1.IPPoolList instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.whereabouts.v1alpha1.IPPoolListFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.whereabouts.v1alpha1.IPPoolList build() {
    IPPoolList buildable = new IPPoolList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    IPPoolListBuilder that = (IPPoolListBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-whereabouts-6.3.1-sources.jar: io/fabric8/openshift/api/model/whereabouts/v1alpha1/IPPoolListBuilder.java <==
package io.fabric8.openshift.api.model.whereabouts.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class IPPoolListBuilder extends IPPoolListFluentImpl<IPPoolListBuilder> implements VisitableBuilder<IPPoolList,IPPoolListBuilder>{
  public IPPoolListBuilder() {
    this(false);
  }
  public IPPoolListBuilder(Boolean validationEnabled) {
    this(new IPPoolList(), validationEnabled);
  }
  public IPPoolListBuilder(IPPoolListFluent<?> fluent) {
    this(fluent, false);
  }
  public IPPoolListBuilder(IPPoolListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new IPPoolList(), validationEnabled);
  }
  public IPPoolListBuilder(IPPoolListFluent<?> fluent,IPPoolList instance) {
    this(fluent, instance, false);
  }
  public IPPoolListBuilder(IPPoolListFluent<?> fluent,IPPoolList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public IPPoolListBuilder(IPPoolList instance) {
    this(instance,false);
  }
  public IPPoolListBuilder(IPPoolList instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  IPPoolListFluent<?> fluent;
  Boolean validationEnabled;
  public IPPoolList build() {
    IPPoolList buildable = new IPPoolList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
